@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 # flake8: noqa: F841
-"""A Simple example using requests-cache with httpbin"""
+"""
+A simple example using requests-cache with httpbin
+"""
 import time
 
 from requests_cache import CachedSession
